bossac-2.1.1 is not a library.
bossac (Rust-edition)
This is the rust version of the bossac utility (reimplements bossac.cpp).
Installation
If you already have rust on your system, you can use it to easily install bossac.